import datetime

from playhouse.shortcuts import model_to_dict

from data_base_model import PatientProblemDiscomfort


class GeneratePatientProblemDiscomfort:

    def __init__(self, consultation, patient_problem):
        self._consultation_id = consultation.get('id')
        self._consultation_type = 'slot'
        self._description = 'test description'
        self._level = 1
        self._patient_problem = patient_problem.get('id')

    def with_consultation_type(self):
        self._consultation_type = 'service_patient'
        return self

    def with_level(self, level):
        self._level = level
        return self

    def generate(self):
        problem_discomfort = PatientProblemDiscomfort(consultation_id=self._consultation_id,
                                                      consultation_type=self._consultation_type,
                                                      created_at=datetime.datetime.now(),
                                                      description=self._description,
                                                      level=self._level,
                                                      patient_problem=self._patient_problem,
                                                      updated_at=datetime.datetime.now())

        problem_discomfort.save()
        return model_to_dict(problem_discomfort)



import datetime

from playhouse.shortcuts import model_to_dict

from qa_data_manager.data_base_model import Files


class File:
    def __init__(self, file_path, file_name, file_size, file_extension):
        self._created_at = datetime.datetime.now()
        self._deleted_at = None
        self._extension = file_extension  # jpg
        self._file = file_path  # /my_compucter/my_files/test.jpg
        self._name = file_name  # test.jpg
        self._preview_for = None
        self._size = file_size  # 210

    def with_deleted_at(self):
        self._deleted_at = datetime.datetime.now()
        return self

    def with_previously_uploaded_file(self, hour):
        self._created_at = datetime.datetime.now() - datetime.timedelta(hours=int(hour))
        return self

    def generate(self):
        file = Files(created_at=self._created_at,
                     deleted_at=self._deleted_at,
                     extension=self._extension,
                     file=self._file,
                     name=self._file,
                     preview_for=self._preview_for,
                     size=self._size,
                     updated_at=self._created_at)

        file.save()
        return model_to_dict(file)



from playhouse.shortcuts import model_to_dict

from qa_data_manager.data_base_model import DoctorInformations

"""
Связь доктора с информациией о докторе.
    Поля:
        * user_id - Индентификатор пользовавтелья; Обязательное поле, устанавливается при инциализации класса из параметра user.
        * category - Категория врача; Принимает String значение; По умолчанию Врач высшей категории.
        * description - Оипсание врача; Принимает String значение; По умолчанию.
        * education - Образование врача; Принимает String значение; По умолчанию.
        * experience - Год начала работы врача; Принимает int значение; По умолчанию.
        * license_status - Статус лицензии врача; По умолчанию no_license.
        
    Метод 
        * with_category():
            - Принимает параметр value.
            - Устанавливает в поле category значение value
        * with_description():
            - Принимает параметр value.
            - Устанавливает в поле description значение value
        * with_education():
            - Принимает параметр value.
            - Устанавливает в поле education значение value
        * with_experience():
            - Принимает параметр value.
            - Устанавливает в поле experience значение value
        * with_active_license() - Устанавливает в поле license_status значение active
        * with_citylab_license() - Устанавливает в поле license_status значение citylab
        * with_commission_license() - Устанавливает в поле license_status значение commission
        * with_commission_license_status() - Устанавливает в поле license_status значение commission_license
        * with_inactive_license() - Устанавливает в поле license_status значение inactive
        * with_package_license() - Устанавливает в поле license_status значение package
        * with_showcase_license() - Устанавливает в поле license_status значение showcase
        * generate():
            - Сохраняет объект BindDoctorInformation в базу данных.
            - Возвращает модель таблицы DoctorInformations с данными сгенерированной связи.
"""


class BindDoctorInformation:

    def __init__(self, user):
        self._user_id = user.get('id')
        self._category = 'Врач высшей категории'
        self._description = 'Направление деятельности: Широкий спектр всех возможных в мире заболеваний.'
        self._education = 'ФакМедМос'
        self._experience = 2000
        self._license_status = 'no_license'

    def with_category(self, value):
        self._category = value
        return self

    def with_description(self, value):
        self._description = value
        return self

    def with_education(self, value):
        self._education = value
        return self

    def with_experience(self, value):
        self._experience = value
        return self

    def with_active_license(self):
        self._license_status = 'active'
        return self

    def with_citylab_license(self):
        self._license_status = 'citylab'
        return self

    def with_commission_license(self):
        self._license_status = 'commission'
        return self

    def with_commission_license_status(self):
        self._license_status = 'commission_license'
        return self

    def with_inactive_license(self):
        self._license_status = 'inactive'
        return self

    def with_package_license(self):
        self._license_status = 'package'
        return self

    def with_showcase_license(self):
        self._license_status = 'showcase'
        return self

    def generate(self):
        doctor_information = DoctorInformations(category=self._category,
                                                description=self._description,
                                                education=self._education,
                                                experience=self._experience,
                                                has_pay_before_minutes=0,
                                                license_status=self._license_status,
                                                pay_before_minutes=None,
                                                percent_income_chat=None,
                                                percent_income_online=None,
                                                user=self._user_id)
        doctor_information.save()

        return model_to_dict(doctor_information)



import datetime as mytime

from playhouse.shortcuts import model_to_dict

from qa_data_manager.data_base_model import Consultations


class GenerateConsultation:

    def __init__(self, doctor, patient, service, slot):
        self._created_at = mytime.datetime.now()
        self._deleted_at = None
        self._doctor = doctor.get('id')
        self._start_at = slot.get('start_at')
        self._end_at = self._start_at + mytime.timedelta(minutes=int(service.get('duration')))
        self._external_id = None
        self._external_type = 'slot'
        self._patient = patient.get('id')
        self._pay_source = 'online'
        self._service = service.get('id')
        self._source = 'admin'
        self._status = 'approved'
        self._type = 'online'

    def with_deleted_at(self):
        self._deleted_at = mytime.datetime.now()
        return self

    def with_external_id(self, ex_id):
        self._external_id = ex_id
        return self

    def with_external_type_service_patient(self):
        self._external_type = 'service_patient'

    def with_pay_source_auto_resume(self):
        self._pay_source = 'auto_resume'
        return self

    def with_pay_source_admin(self):
        self._pay_source = 'admin'
        return self

    def with_pay_source_free(self):
        self._pay_source = 'free'
        return self

    def with_pay_source_on_spot(self):
        self._pay_source = 'on_spot'
        return self

    def with_pay_source_trial(self):
        self._pay_source = 'trial'
        return self

    def with_status_canceled(self):
        self._status = 'canceled'
        return self

    def with_status_completed(self):
        self._status = 'completed'
        return self

    def with_status_expired(self):
        self._status = 'expired'
        return self

    def with_status_not_appeared(self):
        self._status = 'not_appeared'
        return self

    def with_status_open(self):
        self._status = 'open'
        return self

    def with_status_pending(self):
        self._status = 'pending'
        return self

    def with_status_wait_payment(self):
        self._status = 'wait_payment'
        return self

    def with_source_doctor(self):
        self._source = 'doctor'
        return self

    def with_source_patient(self):
        self._source = 'patient'
        return self

    def with_source_public_api(self):
        self._source = 'public_api'
        return self

    def with_source_widget_2(self):
        self._source = 'widget_2.0'
        return self

    def with_type_offline(self):
        self._type = 'offline'
        return self

    def with_type_chat(self):
        self._type = 'chat'
        return self

    def generate(self):
        consultation = Consultations(created_at=self._created_at,
                                     updated_at=self._created_at,
                                     doctor=self._doctor,
                                     patient=self._patient,
                                     pay_source=self._pay_source,
                                     source=self._source,
                                     service=self._service,
                                     external_id=self._external_id,
                                     external_type=self._external_type,
                                     status=self._status,
                                     type=self._type,
                                     start_at=self._start_at,
                                     end_at=self._end_at,
                                     deleted_at=self._deleted_at)
        consultation.save()
        return model_to_dict(consultation)
